Transport
=========

.. currentmodule:: gql.transport

.. autoclass:: gql.transport.transport.Transport

.. autoclass:: gql.transport.local_schema.LocalSchemaTransport

.. autoclass:: gql.transport.requests.RequestsHTTPTransport

.. autoclass:: gql.transport.async_transport.AsyncTransport

.. autoclass:: gql.transport.aiohttp.AIOHTTPTransport

.. autoclass:: gql.transport.websockets.WebsocketsTransport
